@@ -135,7 +135,7 @@ delay_value_changed_cb (GtkWidget *range, GtkScrollType scroll, gdouble value,
 	else if (value > 1000)
 		value = 1000;
 
-	message = g_strdup_printf ("%d %s", CLAMP ((int) floor ((value+50)/100.0) * 100, 100, 1000), _("microseconds"));
+	message = g_strdup_printf (ngettext ("%d milliseconds","%d milliseconds", CLAMP ((int) floor ((value+50)/100.0) * 100, 100, 1000)), CLAMP ((int) floor ((value+50)/100.0) * 100, 100, 1000));
 	gtk_label_set_label ((GtkLabel*) WID ("delay_label"), message);
 	g_free (message);
 
@@ -532,6 +532,13 @@ cursor_font_changed (GConfClient *client,
 	model = gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT(smodel));
 
 	cursor_font = gconf_client_get_string (client, CURSOR_FONT_KEY, NULL);
+
+	/* If there's no value set, then don't select anything, and return */
+	if ( cursor_font == NULL ) {
+		gtk_tree_selection_unselect_all (selection);
+		return;
+	}
+
 	gtk_tree_model_get_iter_root (model, &iter);
 
 	do {
@@ -877,7 +884,7 @@ setup_dialog (GladeXML *dialog, GConfChangeSet *changeset)
 			  G_CALLBACK (event_box_button_press_event), changeset);
 	
 	/* set the timeout value  label with correct value of timeout */
-	message = g_strdup_printf ("%d %s", (int) gtk_range_get_value (GTK_RANGE (WID ("delay_scale"))), _("microseconds"));
+	message = g_strdup_printf (ngettext ("%d milliseconds", "%d milliseconds", (int) gtk_range_get_value (GTK_RANGE (WID ("delay_scale")))), (int) gtk_range_get_value (GTK_RANGE (WID ("delay_scale"))));
 	gtk_label_set_label ((GtkLabel*) WID ("delay_label"), message);
 	g_free (message); 
 	
