@@ -32,7 +32,7 @@
 
 static gboolean sync_changes;
 
-#if DE_DEBUG
+#ifdef DE_DEBUG
 static void
 print_mime_app (const char *mime_type)
 {
@@ -85,9 +85,8 @@ vfs_change_cb (GnomeVFSMIMEMonitor *monitor, GConfClient *client)
 
 	PRINT_STATE;
 
-	if (!sync_changes_cb)
+	if (!sync_changes)
 		return;
-
 	
 	star_app  = gnome_vfs_mime_get_default_application ("text/*");
 	plain_app = gnome_vfs_mime_get_default_application ("text/plain");
@@ -107,7 +106,7 @@ vfs_change_cb (GnomeVFSMIMEMonitor *monitor, GConfClient *client)
 		return;
 	}
 
-#if DE_DEBUG
+#ifdef DE_DEBUG
 	g_message ("Synching text/plain to text/*...");
 #endif
 
